@@ -223,7 +223,8 @@ class Stream(object):
             # read the next twitter status object
             if delimited_string.strip().isdigit():
                 next_status_obj = resp.read( int(delimited_string) )
-                self._data(next_status_obj)
+                if self.running:
+                    self._data(next_status_obj)
 
         if resp.isclosed():
             self.on_closed(resp)
@@ -244,7 +245,7 @@ class Stream(object):
         self.parameters = {'delimited': 'length'}
         if self.running:
             raise TweepError('Stream object already connected!')
-        self.url = '/%s/user.json?delimited=length' % STREAM_VERSION
+        self.url = '/%s/user.json' % STREAM_VERSION
         self.host='userstream.twitter.com'
         if stall_warnings:
             self.parameters['stall_warnings'] = stall_warnings
@@ -253,12 +254,16 @@ class Stream(object):
         if replies:
             self.parameters['replies'] = replies
         if locations and len(locations) > 0:
-            assert len(locations) % 4 == 0
+            if len(locations) % 4 != 0:
+                raise TweepError("Wrong number of locations points, "
+                                 "it has to be a multiple of 4")
             self.parameters['locations'] = ','.join(['%.2f' % l for l in locations])
         if track:
             encoded_track = [s.encode(encoding) for s in track]
             self.parameters['track'] = ','.join(encoded_track)
+
         self.body = urlencode_noplus(self.parameters)
+        self.url = self.url + '?' + self.body
         self._start(async)
 
     def firehose(self, count=None, async=False):
@@ -277,17 +282,15 @@ class Stream(object):
         self.url = '/%s/statuses/retweet.json?delimited=length' % STREAM_VERSION
         self._start(async)
 
-    def sample(self, count=None, async=False):
+    def sample(self, async=False):
         self.parameters = {'delimited': 'length'}
         if self.running:
             raise TweepError('Stream object already connected!')
         self.url = '/%s/statuses/sample.json?delimited=length' % STREAM_VERSION
-        if count:
-            self.url += '&count=%s' % count
         self._start(async)
 
     def filter(self, follow=None, track=None, async=False, locations=None,
-               count=None, stall_warnings=False, languages=None, encoding='utf8'):
+               stall_warnings=False, languages=None, encoding='utf8'):
         self.parameters = {}
         self.headers['Content-type'] = "application/x-www-form-urlencoded"
         if self.running:
@@ -300,10 +303,10 @@ class Stream(object):
             encoded_track = [s.encode(encoding) for s in track]
             self.parameters['track'] = ','.join(encoded_track)
         if locations and len(locations) > 0:
-            assert len(locations) % 4 == 0
+            if len(locations) % 4 != 0:
+                raise TweepError("Wrong number of locations points, "
+                                 "it has to be a multiple of 4")
             self.parameters['locations'] = ','.join(['%.4f' % l for l in locations])
-        if count:
-            self.parameters['count'] = count
         if stall_warnings:
             self.parameters['stall_warnings'] = stall_warnings
         if languages:
